@@ -10,28 +10,16 @@ from mimetypes import guess_type
 from os import path
 from smtplib import SMTP_SSL
 
-from je_mail_thunder import get_mail_thunder_os_environ
 from je_mail_thunder.utils.exception.exception_tags import mail_thunder_content_login_failed
 from je_mail_thunder.utils.save_mail_user_content.mail_thunder_content_save import read_output_content
+from je_mail_thunder.utils.save_mail_user_content.save_on_env import get_mail_thunder_os_environ
 
 
 class SMTPWrapper(SMTP_SSL):
 
     def __init__(self, host: str = "smtp.gmail.com", port: int = 465):
         super().__init__(host, port)
-        user_info = read_output_content()
-        try:
-            if user_info is not None and type(user_info) == dict:
-                if user_info.get("user", None) is not None and user_info.get("password", None) is not None:
-                    self.login(user_info.get("user"), user_info.get("password"))
-            else:
-                user_info = get_mail_thunder_os_environ()
-                if user_info is not None and type(user_info) == dict:
-                    if user_info.get("mail_thunder_user", None) is not None and user_info.get(
-                            "mail_thunder_user_password", None) is not None:
-                        self.login(user_info.get("mail_thunder_user"), user_info.get("mail_thunder_user_password"))
-        except smtplib.SMTPAuthenticationError as error:
-            print(repr(error) + " " + mail_thunder_content_login_failed, file=sys.stderr)
+        self.try_to_login_with_env_or_content()
 
     @staticmethod
     def create_message(message_content: str, message_setting_dict: dict, **kwargs):
@@ -79,6 +67,21 @@ class SMTPWrapper(SMTP_SSL):
         message.attach(mime_part)
         return message
 
+    def try_to_login_with_env_or_content(self):
+        user_info = read_output_content()
+        try:
+            if user_info is not None and type(user_info) == dict:
+                if user_info.get("user", None) is not None and user_info.get("password", None) is not None:
+                    self.login(user_info.get("user"), user_info.get("password"))
+            else:
+                user_info = get_mail_thunder_os_environ()
+                if user_info is not None and type(user_info) == dict:
+                    if user_info.get("mail_thunder_user", None) is not None and user_info.get(
+                            "mail_thunder_user_password", None) is not None:
+                        self.login(user_info.get("mail_thunder_user"), user_info.get("mail_thunder_user_password"))
+        except smtplib.SMTPAuthenticationError as error:
+            print(repr(error) + " " + mail_thunder_content_login_failed, file=sys.stderr)
+
     def create_message_with_attach_and_send(self, message_content: str, message_setting_dict: dict,
                                             attach_file: str, use_html: bool = False):
 
